@@ -2,7 +2,7 @@
  * capture.c: capture data from stdout and stderr
  *
  *
- * Copyright (C) 2007-2010 Michael Brunner <mibru@gmx.de>
+ * Copyright (C) 2007-2012 Michael Brunner <mibru@gmx.de>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -65,14 +65,6 @@ static int recalc_cliplen(pipe_t *pipe)
 {
 	int i;
 	int length=0;
-	int checklen;
-
-	if (pipe->bfill>pipe->clip) {
-		checklen = pipe->clip;
-	}
-	else {
-		checklen = pipe->bfill;
-	}
 
 	for (i=0; i<pipe->bfill; i++) {
 		switch(pipe->buf[i]) {
@@ -149,6 +141,8 @@ int print_stream(pipe_t *pipe)
 
 		if ((pipe->bfill + offset) > clip) {
 			ccount = clip - offset;
+			pipe->buf[ccount] = '\r';
+			ccount++;
 			pipe->buf[ccount] = '\n';
 			ccount++;
 			offset = 0;
@@ -239,7 +233,7 @@ void print_summary(void)
 		fprintf(stderr, "Logapp logfile is: %s\n", logfile.name);
 }
 
-inline int is_rdbuf_empty(pipe_t *pipe)
+int is_rdbuf_empty(pipe_t *pipe)
 {
 	return (pipe->rdbuf.read >= pipe->rdbuf.end);
 }
@@ -346,8 +340,9 @@ int read_pipe(pipe_t *pipe)
 int prepare_buffer(pipe_t* pipe)
 {
 	if (pipe->blen) {
-		/* length = buffer length + escape prefix + escape postfix */
-		int len = pipe->blen + pipe->esccolorlen + 1;
+		/* length = buffer length + escape prefix + escape postfix +
+		 * CR/LF */
+		int len = pipe->blen + pipe->esccolorlen + 2;
 
 		if (!(pipe->dbuf = (char*)malloc(len))) {
 			error_outofmemory();
