@@ -2,7 +2,7 @@
  * configuration.c: logapp configuration handling
  *
  *
- * Copyright (C) 2007-2010 Michael Brunner <mibru@gmx.de>
+ * Copyright (C) 2007-2016 Michael Brunner <mibru@gmx.de>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -54,6 +54,7 @@ config_t config = {
 	.disable_keywords	= NULL,
 	.logname		= "./logapp.log",
 	.logtime		= 0,
+	.logtimerstregexp	= NULL,
 	.logreltime		= 0,
 	.logenv			= 0,
 	.circularlog		= 0,
@@ -294,6 +295,9 @@ arglist_t arglist[] = {
 		"align logged line breaks in charbased mode", 0 },
 	{ 't',  "logtime",	"BOOL",	TBOOL, &config.logtime,
 		"add timestamp to each logged line", 0 },
+	{ '\0', "logtime_rstregexp",	"STRING", TSTRING,
+		&config.logtimerstregexp,
+		"regular expression to reset log time on match", 0 },
 	{ '\0',  "logreltime",	"BOOL",	TBOOL, &config.logreltime,
 		"log relative time with --logtime", 0 },
 	{ '\0',  "logenv",	"BOOL",	TBOOL, &config.logenv,
@@ -376,6 +380,7 @@ void show_configuration(void)
 		config.logname?config.logname:"<none>");
 	message("  append to logfile       %i\n", config.appendlog);
 	message("  log timestamps          %i\n", config.logtime);
+	message("  log time reset regexp   %s\n", config.logtimerstregexp);
 	message("  log relative time       %i\n", config.logreltime);
 	message("  log environment         %i\n", config.logenv);
 	message("  align log writes left   %i\n", config.alignlog);
@@ -666,6 +671,22 @@ int fixup_config(void)
 	if (fixup_pipe(app.pstderr))
 		return -1;
 
+	if (config.logtimerstregexp) {
+		if (strlen(config.logtimerstregexp)) {
+			int regexp_cflags = REG_NOSUB|REG_NEWLINE;
+			if (config.extregexp)
+				regexp_cflags |= REG_EXTENDED;
+
+			if (regcomp(&config.plogtimerstreg,
+				    config.logtimerstregexp, regexp_cflags)) {
+				error("unable to process logtime rst regexp\n");
+				return -1;
+			}
+		} else {
+			config.logtimerstregexp = NULL;
+		}
+	}
+
 	/* Prepare indent string */
 	int maxindentlen = 15;
 	if (app.pstdout->lineprefixlen > app.pstderr->lineprefixlen)
@@ -1059,10 +1080,10 @@ int parse_configline(char* line, char **appconfig_section)
 	/* remove comments and spaces */
 	name = line + strspn(line, " \t");
 
-	if (strlen(name) == 0)
+	if ((strlen(name) == 0) || (*name == '#'))
 		return 0;
 
-	value = name + strcspn(name, " \t=");
+	value = name + strcspn(name, " \t=#");
 
 	*(value) = '\0';
 
@@ -1076,7 +1097,7 @@ int parse_configline(char* line, char **appconfig_section)
 		value++;
 		tmp = strchr(value, '\'');
 	} else {
-		tmp = value + strcspn(value, " \t");
+		tmp = value + strcspn(value, " \t#");
 	}
 	if (tmp == NULL) {
 		warning("unterminated string in config file (line %d)\n",
@@ -1085,7 +1106,7 @@ int parse_configline(char* line, char **appconfig_section)
 	}
 
 	*tmp = '\0';
-	
+
 	/* check if we change to a tagged section */
 	if ((strlen(value)==0) && (strlen(name)>1) && (name[0] == '[')
 		   && (name[strlen(name)-1] == ']') ) {
@@ -1180,7 +1201,7 @@ int get_config(void)
 	/* parse each line */
 	config.configfile = filename;
 	while (fgets(linebuf, LINEBUFSIZE, conffile) != NULL) {
-		linebuf[strcspn(linebuf, "#\n")] = '\0';
+		linebuf[strcspn(linebuf, "\n")] = '\0';
 		if (parse_configline(linebuf, &appconfig_section))
 			return -1;
 	}
