@@ -47,6 +47,8 @@ typedef struct {
 				   found in the application parameter list */
 	char* logname;		/* application output log */
 	int   logtime;		/* add timestamp to each logged line */
+	char* logtimerstregexp; /* regexp to reset logged time */
+	regex_t plogtimerstreg; /* preprocessed regexp to reset logged time */
 	int   logreltime;       /* log relative times */
 	int   logenv;		/* add environment variables to logfile */
 	int   maxlogsize;       /* maximum logfile size in KiB */
