@@ -453,6 +453,14 @@ int logfile_write(logfile_t* logfile, pipe_t* pipe)
 		struct timeval tvtime;
 
 		gettimeofday(&tvtime, NULL);
+		if (config.logtimerstregexp) {
+			if (!regexec(&config.plogtimerstreg, pipe->buf,
+				     pipe->bfill, NULL, 0)) {
+				memcpy(&app.toffset, &tvtime,
+				       sizeof(app.toffset));
+			}
+		}
+
 		stamp_sec = (unsigned) (tvtime.tv_sec - app.toffset.tv_sec);
 		stamp_msec = (tvtime.tv_usec - app.toffset.tv_usec)/1000;
 
