@@ -2,7 +2,7 @@
  * main.c: logapp main file
  *
  *
- * Copyright (C) 2007-2010 Michael Brunner <mibru@gmx.de>
+ * Copyright (C) 2007-2011 Michael Brunner <mibru@gmx.de>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -57,6 +57,8 @@ void error_outofmemory(void)
 
 	ret = write(STDERR_FILENO, string_outofmemory,
 		    sizeof(string_outofmemory));
+	if (ret)
+		exit(EXIT_FAILURE);
 }
 
 #define max(a, b) ((a) > (b) ? (a) : (b))
@@ -215,9 +217,12 @@ void usage(void)
 void version(void)
 {
 	message("%s %s\n", EXECUTABLE, VERSION);
-	message("Build date: %s %s\n", __DATE__, __TIME__);
+	if (DEBUG_BUILD) {
+		message("DEBUG VERSION!\n", __DATE__, __TIME__);
+		message("Build date: %s %s\n", __DATE__, __TIME__);
+	}
 	if (strlen(SVN_REVISION))
-		message("SVN revision: %s\n\n", SVN_REVISION);
+		message("SVN revision: %s\n", SVN_REVISION);
 
 	message("\nCompiletime configuration:\n");
 	message("  PTY support %s\n", CONFIG_SUPPORT_PTY?"enabled":"disabled");
